<?xml version="1.0" encoding="utf-8"?>
<?mso-application progid="Excel.Sheet"?>
<xsl:stylesheet	version="3.4" 
				xmlns="urn:schemas-microsoft-com:office:spreadsheet"
				xmlns:html="http://www.w3.org/TR/REC-html40"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:o="urn:schemas-microsoft-com:office:office"
				xmlns:x="urn:schemas-microsoft-com:office:excel"
				xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
				exclude-result-prefixes="xs">
	<xsl:output method="xml" indent="yes" omit-xml-declaration="no"/>
	
	<xsl:template name='Comment'>
		<xsl:comment>
			PROMAX ELECTRONICA SL 
			Version: Complete_Coverage_Stylesheet 3.4
			Marc Travé 04/09/2013
			
			This file is a transformation file for a XML data file in order to give a Style when opening
			the XML data file using Microsoft Excel document.
			
			This style will provide three diferent sheets:
				1.- The data from the XML file in a more confortable view
				2.- The same data in a table format
				3.- A table format compatible with online converters to KML file format
		</xsl:comment>
	</xsl:template>

	<!-- 1.0 MAIN DISTRIBUTION CODE -->
	<xsl:template match='/' priority="1">
		<xsl:call-template name='Initial_Comment_template'/>
		<xsl:choose>
			<xsl:when test="COVERAGE">
				<xsl:call-template name='Version_Control_template'/>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name='Error_Workbook_template'>
					<xsl:with-param name="error_code" select="'001'"/>
					<xsl:with-param name="text" select="'The main node does not match with the XSL main path.'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name='Version_Control_template'>
		<xsl:choose>
			<xsl:when test="$Coverage_xsl_version >= $Coverage_xml_version">
				<xsl:call-template name='Coverage_template'/>	
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name='Error_Workbook_template'>
					<xsl:with-param name="error_code" select="'002'"/>
					<xsl:with-param name="text">XSL version is not the actual one. Your actual COVERAGE.XML file version is <xsl:value-of 
						select="$Coverage_xml_version"/> and your COVERAGE.XSL file version is <xsl:value-of select="$Coverage_xsl_version"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- 2.0 CODE TEMPLATES -->
	<xsl:template name='Initial_Comment_template'>
		<xsl:comment>
			PROMAX ELECTRONICA SL 
			Version: Coverage 3.4
			Marc Travé 04/09/2013
			
			This file is the result of a transformation process using XSLT in order to obtain a XML file with
			DATA+Stylesheet information from an specific XML only Data file provided by functionalities of
			a RANGER family equipment
		</xsl:comment>
	</xsl:template>
	
	<xsl:template name='Coverage_template'>	
		<Workbook>
			<xsl:call-template name='Styles_template'/>
			<!-- SFC: -->
			<Worksheet ss:Name="Google Earth Format">
				<Table>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="75"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="75"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="50"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="200"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="45"/>
					<xsl:call-template name='google_earth_table_format_template'/>
				</Table>
			</Worksheet>			
			<!-- SFC: -->
			<Worksheet ss:Name="Coverage Data" >
				<Table>
					<ss:Column ss:Width="50"/>
					<ss:Column ss:Width="140"/>
					<ss:Column ss:Width="90"/>
					<ss:Column ss:Width="90"/>
					<ss:Column ss:Width="90"/>
					<ss:Column ss:Width="90"/>
					<ss:Column ss:Width="90"/>
					<xsl:call-template name='Coverage_Workbook_template'/>
					<xsl:call-template name='Information_template'>
						<xsl:with-param name="cell_position" select="2"/>
					</xsl:call-template>
					<xsl:call-template name='Cpoint_template'/>
				</Table>
				<WorksheetOptions xmlns="urn:schemas-microsoft-com:office:excel">
					<PageSetup>
						<Header x:Margin="0.3"/>
						<Footer x:Margin="0.3"/>
						<PageMargins x:Bottom="0.75" x:Left="0.7" x:Right="0.7" x:Top="0.75"/>
					</PageSetup>
					<Unsynced/>
					<Print>
						<ValidPrinterInfo/>
						<PaperSizeIndex>9</PaperSizeIndex>
						<HorizontalResolution>600</HorizontalResolution>
						<VerticalResolution>600</VerticalResolution>
					</Print>
					<Selected/>
					<Panes>
						<Pane>
							<Number>3</Number>
							<ActiveRow>2</ActiveRow>
							<ActiveCol>2</ActiveCol>
						</Pane>
					</Panes>
					<ProtectObjects>False</ProtectObjects>
					<ProtectScenarios>False</ProtectScenarios>
				</WorksheetOptions>
			</Worksheet>
			<Worksheet ss:Name="Table Format">
				<Table>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="95"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="80"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="70"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="85"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="85"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="85"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="105"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="90"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="85"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="60"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="60"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="70"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="70"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="60"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="85"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="60"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="80"/>
					<xsl:call-template name='Cpoint_table_format_template'/>
				</Table>
			</Worksheet>
			<!-- SFC: UNCOMMENT<Worksheet ss:Name="Google Earth Format">
				<Table>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="75"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="75"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="50"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="200"/>
					<ss:Column  ss:AutoFitWidth="1" ss:Width="45"/>
					<xsl:call-template name='google_earth_table_format_template'/>
				</Table>
			</Worksheet> -->
        </Workbook>
	</xsl:template>
	
	<!-- 2.1 STRUCTURE TEMPLATES -->
	<xsl:template name='Coverage_Workbook_template'>
		<Row/>
		<Row ss:Index="2" ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String"><xsl:value-of select="COVERAGE/@trademark"/></Data>
			</Cell>
		</Row>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String"><xsl:value-of select="COVERAGE/@equipment"/></Data>
			</Cell>
			<Cell ss:StyleID="s20">
				<Data ss:Type="String"><xsl:value-of select="COVERAGE/@version"/></Data>
			</Cell>
			<Cell ss:StyleID="s20">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/@sn"/></Data>
			</Cell>
		</Row>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String"><xsl:value-of select="COVERAGE/@band"/></Data>
			</Cell>
			<Cell ss:StyleID="s20">
				<Data ss:Type="String"><xsl:value-of select="COVERAGE/@date"/></Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='Information_template'>
		<xsl:param name="cell_position" />
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="COVERAGE/INFORMATION">
			<Row ss:Index="6" ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Description:</Data>
				</Cell>
				<xsl:for-each select="DESCRIPTION">
					<Cell ss:StyleID="s24">
						<Data ss:Type="String"><xsl:value-of select="current()"/></Data>
					</Cell>
				</xsl:for-each>
			</Row>
			<Row ss:AutoFitHeight="1"/>
			<xsl:for-each select="SETTINGS">
				<xsl:call-template name='Settings_template'>
					<xsl:with-param name="cell_position" select="$cell_position"/>
				</xsl:call-template>
			</xsl:for-each>
			<Row ss:AutoFitHeight="1"/>
			<xsl:for-each select="CHANNEL">
				<xsl:call-template name='Channel_template'>
					<xsl:with-param name="cell_position" select="$cell_position"/>
				</xsl:call-template>
			</xsl:for-each> 
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='Settings_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Settings:</Data>
			</Cell>
		</Row>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Sampling Time:</Data>
			</Cell>
			<xsl:for-each select="SAMPLING_TIME">
				<xsl:call-template name='number_value_units_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</xsl:for-each>
		</Row>
	</xsl:template>
	
	<xsl:template name='Channel_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Channel:</Data>
			</Cell>
		</Row>
		<xsl:for-each select="MEASUREMENTS">
			<xsl:choose>
				<xsl:when test="DVB-T2">
					<xsl:call-template name='dvbt2_template'/>
				</xsl:when>
				<xsl:when test="DVB-T">
					<xsl:call-template name='dvbt_template'/>
				</xsl:when>
				<xsl:when test="DVB-C">
					<xsl:call-template name='dvbc_template'/>					
				</xsl:when>
				<!-- SFC: -->
				<xsl:when test="DAB">
					<xsl:call-template name='dab_template'/>					
				</xsl:when>
				<xsl:when test="DVB-C2">
					<xsl:call-template name='dvbc2_template'/>					
				</xsl:when>
				<xsl:when test="DVB-S">
					<xsl:call-template name='dvbs_template'/>					
				</xsl:when>				
				<xsl:when test="DVB-S2">
					<xsl:call-template name='dvbs2_template'/>					
				</xsl:when>		
				<xsl:when test="ISDB-T">
					<xsl:call-template name='isdbt_template'/>					
				</xsl:when>				
				<xsl:when test="ATSC">
					<xsl:call-template name='atsc_template'/>					
				</xsl:when>				
				<!-- SFC: -->
				<xsl:when test="FM">
					<xsl:call-template name='fm_template'/>	
				</xsl:when>
				<xsl:when test="ANALOGTER">
					<xsl:call-template name='analog_template'/>	
				</xsl:when>
				<xsl:otherwise>
					<xsl:call-template name='Error_Cell_template'>
						<xsl:with-param name="error_code" select="'003'"/>
						<xsl:with-param name="text" select="'There is no match between Signal type node and this XSD templates list.'"/>
						<xsl:with-param name="cell_position" select="$cell_position"/>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='dvbt2_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DVB-T2</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DVB-T2/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="DVB-T2/PROFILE">
			<xsl:call-template name='profile_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='dvbt_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DVB-T</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DVB-T/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="DVB-T/PRIORITY">
			<xsl:call-template name='priority_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<!-- SFC: -->
	<xsl:template name='dvbc_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DVB-C</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DVB-C/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
	</xsl:template>
	
	<xsl:template name='dvbc2_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DVB-C2</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DVB-C2/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="DVB-C2/DSLICE">
			<xsl:call-template name='dslice_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>	
	
	<xsl:template name='dvbs_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DVB-S</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DVB-S/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>		
	
	<xsl:template name='dvbs2_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DVB-S2</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DVB-S2/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="DVB-S2/ISI">
			<xsl:call-template name='isi_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>			
	
	<xsl:template name='dab_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">DAB</Data>
			</Cell>
		</Row>
		<xsl:for-each select="DAB/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="DAB/PRIORITY">
			<xsl:call-template name='priority_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='isdbt_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">ISDB-T</Data>
			</Cell>
		</Row>
		<xsl:for-each select="ISDB-T/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="ISDB-T/LAYER">
			<xsl:call-template name='layer_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>

	<xsl:template name='atsc_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">ATSC</Data>
			</Cell>
		</Row>
		<xsl:for-each select="ATSC/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>	
	<!-- SFC: -->
	
	<xsl:template name='fm_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">FM</Data>
			</Cell>
		</Row>
		<xsl:for-each select="FM">
			<xsl:call-template name='fm_parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
	</xsl:template>
	
	<xsl:template name='analog_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="2" ss:StyleID="s20">
				<Data ss:Type="String">Signal:</Data>
			</Cell>
			<Cell ss:StyleID="s24">
				<Data ss:Type="String">ANALOGIC</Data>
			</Cell>
		</Row>
		<xsl:for-each select="ANALOG/PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
		<Row ss:AutoFitHeight="1"/>
		<xsl:for-each select="ANALOG/PLP">
			<xsl:call-template name='plp_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='priority_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Priority:</Data>
			</Cell>
			<xsl:call-template name='value_nl_template'>
				<xsl:with-param name="cell_position" select="$cell_position+1"/>
			</xsl:call-template>
		</Row>
		<xsl:for-each select="PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
	</xsl:template>
	
	<!-- SFC: -->
	<xsl:template name='layer_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Layer:</Data>
			</Cell>
			<xsl:call-template name='value_nl_template'>
				<xsl:with-param name="cell_position" select="$cell_position+1"/>
			</xsl:call-template>
		</Row>
		<xsl:for-each select="PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
	</xsl:template>

	<xsl:template name='isi_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">ISI:</Data>
			</Cell>
			<xsl:call-template name='value_nl_template'>
				<xsl:with-param name="cell_position" select="$cell_position+1"/>
			</xsl:call-template>
		</Row>
		<xsl:for-each select="PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
	</xsl:template>	
	<!-- SFC: -->
	
	<xsl:template name='profile_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Profile:</Data>
			</Cell>
			<xsl:call-template name='value_nl_template'>
				<xsl:with-param name="cell_position" select="$cell_position+1"/>
			</xsl:call-template>
		</Row>
		<xsl:for-each select="PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
		<xsl:for-each select="PLP">
			<xsl:call-template name='plp_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='plp_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">PLP:</Data>
			</Cell>
			<xsl:call-template name='number_value_nl_template'>
				<xsl:with-param name="cell_position" select="$cell_position+1"/>
			</xsl:call-template>
		</Row>
		<xsl:for-each select="PARAMETERS">
			<xsl:call-template name='parameters_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='Cpoint_template'>
		<xsl:for-each select="COVERAGE/CPOINT">
			<Row ss:AutoFitHeight="1"/>
			<xsl:call-template name='Cpoint_heading_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
			<xsl:call-template name='Cpoint_data_template'>
				<xsl:with-param name="cell_position" select="2"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='Cpoint_data_template'>
		<xsl:param name="cell_position"/>
		<xsl:for-each select="GPS">
			<xsl:call-template name='gps_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
		<xsl:for-each select="STATUS">
			<xsl:call-template name='status_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="MEASURES">
			<xsl:call-template name='measures_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="gps_template">
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">GPS Locked:</Data>
			</Cell>
			<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
				<Data ss:Type="String"><xsl:value-of select="@locked"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+2}" ss:StyleID="s20">
				<Data ss:Type="String">Latitude:</Data>
			</Cell>
			<Cell ss:Index="{$cell_position+3}" ss:StyleID="s24">
				<Data ss:Type="Number"><xsl:value-of select="@latitude"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+4}" ss:StyleID="s20">
				<Data ss:Type="String">Longitude:</Data>
			</Cell>
			<Cell ss:Index="{$cell_position+5}" ss:StyleID="s24">
				<Data ss:Type="Number"><xsl:value-of select="@longitude"/></Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name="status_template">
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Status:</Data>
			</Cell>
			<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
				<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<!-- SFC: Whatever we modify/add here, will have effect in the "Coverage Data" excel tab. It finishes where it says "BLOCK FINISHED" -->
	<xsl:template name="measures_template">
		<xsl:param name="cell_position"/>
		<xsl:for-each select="POWER">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Power:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">CN:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<!-- SFC: -->
		<xsl:for-each select="VA">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">VA:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>			
		<!-- SFC: -->
		<xsl:for-each select="MER">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">MER:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="CBER">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">CBER:</Data>
				</Cell>
				<xsl:call-template name='value_range_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="SER">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">SER:</Data>
				</Cell>
				<xsl:call-template name='value_range_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>		
		<!-- SFC: -->
		<xsl:for-each select="VBER">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">VBER:</Data>
				</Cell>
				<xsl:call-template name='value_range_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>			
		<!-- SFC: -->
		<xsl:for-each select="LBER">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">LBER:</Data>
				</Cell>
				<xsl:call-template name='value_range_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="LM">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">LM:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="LEVEL">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Level:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="FMDEVIATION">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">FM deviation:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="OFFSET">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Offset:</Data>
				</Cell>
				<xsl:call-template name='units_range_value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
	</xsl:template>
	<!-- SFC: "BLOCK FINISHED". It finishes the "Coverage Data" -->
	
	<xsl:template name='Cpoint_heading_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">Coverage Point:</Data>
			</Cell>
			<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
				<Data ss:Type="Number"><xsl:value-of select="@id"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
				<Data ss:Type="String"><xsl:value-of select="@date"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+3}" ss:StyleID="s24">
				<Data ss:Type="String"><xsl:value-of select="@time"/></Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='fm_parameters_template'>
		<xsl:param name="cell_position"/>
		<xsl:for-each select="RDS">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">RDS:</Data>
				</Cell>
				<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
					<Data ss:Type="String"><xsl:value-of select="@ps"/></Data>
				</Cell>
				<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
					<Data ss:Type="String"><xsl:value-of select="@pi"/> - <xsl:value-of select="@quality"/><xsl:value-of select="@units"/></Data>
				</Cell>
			</Row>
		</xsl:for-each>
		<xsl:for-each select="STATUS">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Status:</Data>
				</Cell>
				<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
					<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
				</Cell>
				<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
					<Data ss:Type="String"><xsl:value-of select="@locked"/></Data>
				</Cell>
			</Row>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='parameters_template'>
		<xsl:param name="cell_position"/>
		<xsl:for-each select="DVBT2_PROFILE">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">DVB-T2 Profile:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="BANDWIDTH">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Bandwidth:</Data>
				</Cell>
				<xsl:call-template name='number_value_units_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="FFT_MODE">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">FFT Mode:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="PILOT_PATTERN">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Pilot Pattern:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="GUARD_INTERVAL">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Guard Interval:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="CONSTELLATION_ROTATION">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Constellation Rotation:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="CONSTELLATION">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Constellation:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="CODERATE">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Coderate:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="SPECTRALINVERSION">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Spectral Inversion:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="DVBT_HIERARCHY">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">DVB-T Hierarchy:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="SYMBOLRATE">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Symbolrate:</Data>
				</Cell>
				<xsl:call-template name='number_value_units_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<xsl:for-each select="ROLL_OFF_FACTOR">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Roll of factor:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>
		<!-- SFC: -->
		<xsl:for-each select="TIME_INTERLEAVING">
			<Row ss:AutoFitHeight="1">
				<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
					<Data ss:Type="String">Time Interleaving:</Data>
				</Cell>
				<xsl:call-template name='value_nl_template'>
					<xsl:with-param name="cell_position" select="$cell_position+1"/>
				</xsl:call-template> 
			</Row>
		</xsl:for-each>		
		<!-- SFC: -->
	</xsl:template>
	
	<!-- SFC: -->
	<xsl:template name='dslice_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">DSLICE:</Data>
			</Cell>
			<xsl:call-template name='value_nl_template'>
				<xsl:with-param name="cell_position" select="$cell_position+1"/>
			</xsl:call-template>
		</Row>
		<xsl:for-each select="PLP">
			<xsl:call-template name='plp_template'>
				<xsl:with-param name="cell_position" select="$cell_position"/>
			</xsl:call-template> 
		</xsl:for-each>
	</xsl:template>
	<!-- SFC: -->
	
	<xsl:template name="gps_table_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@latitude"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@longitude"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@locked"/></Data>
		</Cell>
	</xsl:template>

	<!-- SFC: -->
	<xsl:template name="Cpoint_table_dvbt2_dvbc2_dvbs2_measures_template">
		<xsl:for-each select="POWER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="MER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="12"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="14"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="LBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="16"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="LM">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="18"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="OFFSET">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="20"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Cpoint_table_dvbt_dvbs_isdbt_measures_template">
		<xsl:for-each select="POWER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="MER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="12"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="14"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="VBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="16"/>
			</xsl:call-template>
		</xsl:for-each>		
		<xsl:for-each select="LM">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="18"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="OFFSET">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="20"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name="Cpoint_table_atsc_measures_template">
		<xsl:for-each select="POWER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="MER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="12"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="SER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="14"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="VBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="16"/>
			</xsl:call-template>
		</xsl:for-each>		
		<xsl:for-each select="LM">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="18"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="OFFSET">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="20"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>	
	
	<xsl:template name="Cpoint_table_dvbc_measures_template">
		<xsl:for-each select="POWER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="MER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="12"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="14"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="LM">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="16"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="OFFSET">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="18"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>	
	
	<xsl:template name="Cpoint_table_dab_measures_template">
		<xsl:for-each select="POWER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="MER">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="12"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CBER">
			<xsl:call-template name='scientific_number_value_range_template'>
				<xsl:with-param name="cell_position" select="14"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>	
	<!-- SFC: -->
	
	<xsl:template name="Cpoint_table_fm_measures_template">
		<xsl:for-each select="LEVEL">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="FMDEVIATION">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>
	</xsl:template>

	<!-- SFC: -->
	<xsl:template name="Cpoint_table_analog_measures_template">
		<xsl:for-each select="LEVEL">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="8"/>
			</xsl:call-template>
		</xsl:for-each>
		<xsl:for-each select="CN">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="10"/>
			</xsl:call-template>
		</xsl:for-each>		
		<xsl:for-each select="VA">
			<xsl:call-template name='number_value_range_template'>
				<xsl:with-param name="cell_position" select="12"/>
			</xsl:call-template>
		</xsl:for-each>		
	</xsl:template> 
	<!-- SFC: -->
	
	<xsl:template name="status_table_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='Cpoint_table_format_template'>
		<xsl:call-template name='Cpoint_table_heading_template'/>
		<xsl:for-each select="COVERAGE/CPOINT">
			<xsl:call-template name='Cpoint_table_data_template'/>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='Cpoint_table_data_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="1" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="@id"/></Data>
			</Cell>
			<Cell ss:Index="2" ss:StyleID="s23">
				<Data ss:Type="String"><xsl:value-of select="@date"/></Data>
			</Cell>
			<Cell ss:Index="3" ss:StyleID="s23">
				<Data ss:Type="String"><xsl:value-of select="@time"/></Data>
			</Cell>
			<xsl:for-each select="GPS">
				<xsl:call-template name='gps_table_template'>
					<xsl:with-param name="cell_position" select="4"/>
				</xsl:call-template>
			</xsl:for-each>
			<xsl:for-each select="STATUS">
				<xsl:call-template name='status_table_template'>
					<xsl:with-param name="cell_position" select="7"/>
				</xsl:call-template>
			</xsl:for-each>
			<xsl:for-each select="MEASURES">
				<!-- SFC: -->
 				<xsl:if test="$signal_type = 'DVB-T2'">
					<xsl:call-template name='Cpoint_table_dvbt2_dvbc2_dvbs2_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'DVB-T'">
					<xsl:call-template name='Cpoint_table_dvbt_dvbs_isdbt_measures_template'/>
				</xsl:if>
 				<xsl:if test="$signal_type = 'DVB-C2'">
					<xsl:call-template name='Cpoint_table_dvbt2_dvbc2_dvbs2_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'DVB-C'">
					<xsl:call-template name='Cpoint_table_dvbc_measures_template'/>
				</xsl:if>	
				<xsl:if test="$signal_type = 'DVB-S'">
					<xsl:call-template name='Cpoint_table_dvbt_dvbs_isdbt_measures_template'/>
				</xsl:if>				
				<xsl:if test="$signal_type = 'DVB-S2'">
					<xsl:call-template name='Cpoint_table_dvbt2_dvbc2_dvbs2_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'ISDB-T'">
					<xsl:call-template name='Cpoint_table_dvbt_dvbs_isdbt_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'ATSC'">
					<xsl:call-template name='Cpoint_table_atsc_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'DAB'">
					<xsl:call-template name='Cpoint_table_dab_measures_template'/>
				</xsl:if>				
				<!-- SFC: -->
				<xsl:if test="$signal_type = 'FM'">
					<xsl:call-template name='Cpoint_table_fm_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'ANALOG'">
					<xsl:call-template name='Cpoint_table_analog_measures_template'/>
				</xsl:if>
				<xsl:if test="$signal_type = 'ERROR'">
					<xsl:call-template name='Error_Cell_No_Row_template'>
						<xsl:with-param name="error_code" select="'005'"/>
						<xsl:with-param name="text" select="'There is no match between Signal type node and this XSD templates list.'"/>
						<xsl:with-param name="cell_position" select="8"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:for-each>
		</Row>
	</xsl:template>
	
	<!-- SFC: Everything below this point and until the word "BLOCK FINISH" has to do with the excel tab "Table Format" -->
	<xsl:template name='Cpoint_table_dvbt2_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LBER</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LBER range</Data>
		</Cell>
		<!-- SFC: -->
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<!-- SFC: -->
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>	
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='Cpoint_table_dvbt_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<!-- SFC: -->
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<!-- SFC: -->
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
		<!-- SFC: -->
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VBER range</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<!-- SFC: -->
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='Cpoint_table_fm_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$level_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$level_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Level Range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$fm_deviation_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$fm_deviation_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Deviation Range</Data>
		</Cell>
	</xsl:template>
	
	<!-- SFC: -->
	<xsl:template name='Cpoint_table_dvbc_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='Cpoint_table_dvbc2_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LBER range</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>	
	
	<xsl:template name='Cpoint_table_dvbs_isdbt_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VBER range</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>	

	<xsl:template name='Cpoint_table_dvbs2_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LBER range</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>	

	<xsl:template name='Cpoint_table_atsc_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">SER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">SER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VBER range</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$lm_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$lm_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">LM range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$offset_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$offset_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Offset range</Data>
		</Cell>
	</xsl:template>	
	
	<xsl:template name='Cpoint_table_dab_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$power_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$power_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Power range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$mer_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$mer_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">MER range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CBER range</Data>
		</Cell>
	</xsl:template>	
	
	<xsl:template name='Cpoint_table_analog_heading_template'>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$level_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$level_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">Level Range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$cn_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$cn_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">CN Range</Data>
		</Cell>
		<Cell ss:StyleID="s21">
			<Data ss:Type="String"><xsl:value-of select="$va_label"/><xsl:value-of select="$open_label"/>
				<xsl:value-of select="$va_units_label"/><xsl:value-of select="$close_label"/>
			</Data>
		</Cell>		
		<Cell ss:StyleID="s21">
			<Data ss:Type="String">VA Range</Data>
		</Cell>		
	</xsl:template>
	<!-- SFC: -->
	
	<xsl:template name='Cpoint_table_heading_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Coverage Point</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Date</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Time</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Latitude</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Longitude</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">GPS Locked</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Status</Data>
			</Cell>
			<xsl:for-each select="COVERAGE/INFORMATION/CHANNEL/MEASUREMENTS">
				<xsl:choose>
					<xsl:when test="DVB-T2">
						<xsl:call-template name='Cpoint_table_dvbt2_heading_template'/>
					</xsl:when>
					<xsl:when test="DVB-T">
						<xsl:call-template name='Cpoint_table_dvbt_heading_template'/>
					</xsl:when>
					<xsl:when test="FM">
						<xsl:call-template name='Cpoint_table_fm_heading_template'/>	
					</xsl:when>
					<!-- SFC: -->
					<xsl:when test="ANALOGTER">
						<xsl:call-template name='Cpoint_table_analog_heading_template'/>	
					</xsl:when>
					<xsl:when test="DVB-C">
						<xsl:call-template name='Cpoint_table_dvbc_heading_template'/>	
					</xsl:when>					
					<xsl:when test="DVB-C2">
						<xsl:call-template name='Cpoint_table_dvbc2_heading_template'/>	
					</xsl:when>	
					<xsl:when test="DAB">
						<xsl:call-template name='Cpoint_table_dab_heading_template'/>	
					</xsl:when>					
					<xsl:when test="DVB-S">
						<xsl:call-template name='Cpoint_table_dvbs_isdbt_heading_template'/>	
					</xsl:when>			
					<xsl:when test="DVB-S2">
						<xsl:call-template name='Cpoint_table_dvbs2_heading_template'/>	
					</xsl:when>	
					<xsl:when test="ISDB-T">
						<xsl:call-template name='Cpoint_table_dvbs_isdbt_heading_template'/>	
					</xsl:when>	
					<xsl:when test="ATSC">
						<xsl:call-template name='Cpoint_table_atsc_heading_template'/>	
					</xsl:when>						
					<!-- SFC: -->
					<xsl:otherwise>
						<xsl:call-template name='Error_Cell_No_Row_template'>
							<xsl:with-param name="error_code" select="'004'"/>
							<xsl:with-param name="text" select="'There is no match between Signal type node and this XSD templates list.'"/>
							<xsl:with-param name="cell_position" select="8"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</Row>
	</xsl:template>
	<!-- SFC: "BLOCK FINISH". Here finish everything that has to do with the excel tab "Table Format" -->
	
	<xsl:template name='google_earth_table_format_template'>
		<xsl:call-template name='google_earth_table_heading_template'/>
		<xsl:call-template name='google_earth_first_row_table_data_template'>
			<xsl:with-param name="cell_position" select="1"/>
		</xsl:call-template>
		<xsl:for-each select="COVERAGE/CPOINT">
			<xsl:if test="position()!=1">
				<xsl:call-template name='google_earth_table_data_template'>
					<xsl:with-param name="cell_position" select="1"/>
				</xsl:call-template>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<xsl:template name='google_earth_table_heading_template'>
		<Row ss:AutoFitHeight="1">
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Latitude</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Longitude</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Name</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Description</Data>
			</Cell>
			<Cell ss:StyleID="s21">
				<Data ss:Type="String">Icon</Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='google_earth_first_row_table_data_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/CPOINT/GPS/@latitude"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/CPOINT/GPS/@longitude"/></Data>
			</Cell>
			<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
				<Data ss:Type="Number"><xsl:value-of select="COVERAGE/CPOINT/@id"/></Data>
			</Cell>
 			<xsl:if test="$signal_type = 'DVB-T2'">
				<xsl:call-template name='google_earth_DVBT2_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'DVB-T'">
				<xsl:call-template name='google_earth_DVBT_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<!-- SFC: --> 
			<xsl:if test="$signal_type = 'DVB-C'">
				<xsl:call-template name='google_earth_DVBC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<xsl:if test="$signal_type = 'DVB-C2'">
				<xsl:call-template name='google_earth_DVBC2_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:if test="$signal_type = 'DAB'">
				<xsl:call-template name='google_earth_DAB_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>	
			<xsl:if test="$signal_type = 'DVB-S'">
				<xsl:call-template name='google_earth_DVBS_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'DVB-S2'">
				<xsl:call-template name='google_earth_DVBS2_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>	
			<xsl:if test="$signal_type = 'ISDB-T'">
				<xsl:call-template name='google_earth_ISDBT_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'ATSC'">
				<xsl:call-template name='google_earth_ATSC_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>				
			<!-- SFC: -->			
 			<xsl:if test="$signal_type = 'FM'">
				<xsl:call-template name='google_earth_FM_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<xsl:if test="$signal_type = 'ANALOG'">
				<xsl:call-template name='google_earth_ANALOG_table_heading_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ERROR'">
				<xsl:call-template name='Error_Cell_No_Row_template'>
					<xsl:with-param name="error_code" select="'006'"/>
					<xsl:with-param name="text" select="'There is no match between Sygnal type node and this XSD tempataes list.'"/>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<Cell ss:Index="{$cell_position+4}" ss:StyleID="s23">
				<Data ss:Type="Number">55</Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='google_earth_DVBT2_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='google_earth_DVBT_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<!-- SFC: -->
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
				<!-- SFC: -->
			</Data>
		</Cell>
	</xsl:template>

	<!-- SFC: --> 
	<xsl:template name='google_earth_DVBC_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>	

	<xsl:template name='google_earth_DVBC2_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	
	<xsl:template name='google_earth_DAB_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	
	<xsl:template name='google_earth_DVBS_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	
	<xsl:template name='google_earth_DVBS2_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>		

	<xsl:template name='google_earth_ISDBT_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>

	<xsl:template name='google_earth_ATSC_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/MER/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>	
	
	<xsl:template name='google_earth_ANALOG_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@units"/>   CN: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/CN/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/CN/@units"/>
			</Data>
		</Cell>
	</xsl:template>	 	
	<!-- SFC: -->	
	
	<xsl:template name='google_earth_FM_table_heading_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@units"/>    FM Deviation: <xsl:value-of 
				select="COVERAGE/CPOINT/MEASURES/FMDEVIATION/@value"/>
				<xsl:value-of select="COVERAGE/CPOINT/MEASURES/FMDEVIATION/@units"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='google_earth_DVBT2_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='google_earth_DVBT_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
			<!-- SFC: -->
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			<!-- SFC: -->
			</Data>
		</Cell>
	</xsl:template>

	<!-- SFC: --> 
	<xsl:template name='google_earth_DVBC_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>	

	<xsl:template name='google_earth_DVBC2_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>	
	
	<xsl:template name='google_earth_DAB_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	
	<xsl:template name='google_earth_DVBS_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	
	<xsl:template name='google_earth_DVBS2_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>	

	<xsl:template name='google_earth_ISDBT_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>

	<xsl:template name='google_earth_ATSC_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Power: <xsl:value-of select="MEASURES/POWER/@value"/>
				<xsl:value-of select="MEASURES/POWER/@units"/>   MER: <xsl:value-of 
				select="MEASURES/MER/@value"/>
				<xsl:value-of select="MEASURES/MER/@units"/>
			</Data>
		</Cell>
	</xsl:template>	
	
	<xsl:template name='google_earth_ANALOG_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="MEASURES/LEVEL/@value"/>
				<xsl:value-of select="MEASURES/LEVEL/@units"/>   CN: <xsl:value-of 
				select="MEASURES/CN/@value"/>
				<xsl:value-of select="MEASURES/CN/@units"/>
			</Data>
		</Cell>
	</xsl:template>		
	<!-- SFC: --> 	
	
	<xsl:template name='google_earth_FM_table_template'>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String">Level: <xsl:value-of select="MEASURES/LEVEL/@value"/>
				<xsl:value-of select="MEASURES/LEVEL/@units"/>    FM Deviation: <xsl:value-of 
				select="MEASURES/FMDEVIATION/@value"/>
				<xsl:value-of select="MEASURES/FMDEVIATION/@units"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='google_earth_table_data_template'>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<xsl:for-each select="GPS">
				<xsl:call-template name='google_earth_gps_table_template'>
					<xsl:with-param name="cell_position" select="1"/>
				</xsl:call-template>
			</xsl:for-each>
			<Cell ss:Index="{$cell_position+2}"  ss:StyleID="s23">
				<Data ss:Type="Number">
					<xsl:value-of select="@id"/>
				</Data>
			</Cell>
			<xsl:if test="$signal_type = 'DVB-T2'">
				<xsl:call-template name='google_earth_DVBT2_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'DVB-T'">
				<xsl:call-template name='google_earth_DVBT_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<!-- SFC: --> 
			<xsl:if test="$signal_type = 'DVB-C'">
				<xsl:call-template name='google_earth_DVBC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'DVB-C2'">
				<xsl:call-template name='google_earth_DVBC2_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>				
			<xsl:if test="$signal_type = 'DAB'">
				<xsl:call-template name='google_earth_DAB_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>		
			<xsl:if test="$signal_type = 'DVB-S'">
				<xsl:call-template name='google_earth_DVBS_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<xsl:if test="$signal_type = 'DVB-S2'">
				<xsl:call-template name='google_earth_DVBS2_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ISDB-T'">
				<xsl:call-template name='google_earth_ISDBT_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ATSC'">
				<xsl:call-template name='google_earth_ATSC_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>			
			<!-- SFC: --> 			
 			<xsl:if test="$signal_type = 'FM'">
				<xsl:call-template name='google_earth_FM_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<xsl:if test="$signal_type = 'ANALOG'">
				<xsl:call-template name='google_earth_ANALOG_table_template'>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="$signal_type = 'ERROR'">
				<xsl:call-template name='Error_Cell_No_Row_template'>
					<xsl:with-param name="error_code" select="'007'"/>
					<xsl:with-param name="text" select="'There is no match between Sygnal type node and this XSD templates list.'"/>
					<xsl:with-param name="cell_position" select="$cell_position+3"/>
				</xsl:call-template>
			</xsl:if> 
			<Cell ss:Index="{$cell_position+4}"  ss:StyleID="s23">
				<xsl:if test="position()=last()">
					<Data ss:Type="Number">55</Data>
				</xsl:if>
				<xsl:if test="position()!=last()">
					<Data ss:Type="Number">121</Data>
				</xsl:if>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name="google_earth_gps_table_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number">
				<xsl:value-of select="@latitude"/>
			</Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="Number">
				<xsl:value-of select="@longitude"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<!-- 3.0 GENERIC USEFUL TEMPLATES -->
	<xsl:template name='Error_Workbook_template'>
		<xsl:param name="error_code"/>
		<xsl:param name="text"/>
		<Workbook>
			<xsl:call-template name='Styles_template'/>
			<Worksheet ss:Name="Error Message">
				<Table>
					<Row ss:Index="2" ss:AutoFitHeight="1">
						<Cell ss:Index="2" ss:StyleID="s20">
							<Data ss:Type="String">
								<xsl:value-of select="$Error_Code_text"/><xsl:value-of select="$error_code"/> - <xsl:value-of select="$text"/>
							</Data>
						</Cell>
					</Row>
				</Table>
			</Worksheet>
        </Workbook>
	</xsl:template>

	<xsl:template name='Error_Cell_template'>
		<xsl:param name="error_code"/>
		<xsl:param name="text"/>
		<xsl:param name="cell_position"/>
		<Row ss:AutoFitHeight="1">
			<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
				<Data ss:Type="String">
					<xsl:value-of select="$Error_Code_text"/><xsl:value-of select="$error_code"/> - <xsl:value-of select="$text"/>
				</Data>
			</Cell>
		</Row>
	</xsl:template>
	
	<xsl:template name='Error_Cell_No_Row_template'>
		<xsl:param name="error_code"/>
		<xsl:param name="text"/>
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s20">
			<Data ss:Type="String">
				<xsl:value-of select="$Error_Code_text"/><xsl:value-of select="$error_code"/> - <xsl:value-of select="$text"/>
			</Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name='Blank_Workbook_template'>
		<Workbook>
			<xsl:call-template name='Styles_template'/>
			<Worksheet ss:Name="Sheet 1">
				<Table/>
			</Worksheet>
			<xsl:call-template name='Additional_blank_sheet_template'/>
        </Workbook>
	</xsl:template>
	
	<xsl:template name='Additional_blank_sheet_template'>
		<Worksheet ss:Name="Sheet 2">
			<Table/>
		</Worksheet>
		<Worksheet ss:Name="Sheet 3">
			<Table/>
		</Worksheet>
	</xsl:template>
	
	<xsl:template name="units_range_value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_units_range_value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_units_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_units_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23" >
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="scientific_number_value_range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s33">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="range_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="units_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s23">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="units_range_value_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_units_range_value_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+2}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_units_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_units_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_range_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_range_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
		<Cell ss:Index="{$cell_position+1}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="number_value_nl_template">	
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="Number"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="value_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@value"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="range_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@range"/></Data>
		</Cell>
	</xsl:template>
	
	<xsl:template name="units_nl_template">
		<xsl:param name="cell_position"/>
		<Cell ss:Index="{$cell_position}" ss:StyleID="s24">
			<Data ss:Type="String"><xsl:value-of select="@units"/></Data>
		</Cell>
	</xsl:template>
	
	<!-- 4.0 GENERIC VARIABLES -->
	<xsl:variable name="Coverage_xsl_version" as="xs:string" select="'3.3'" />

	<xsl:variable name="Coverage_xml_version" as="xs:string">
		<xsl:value-of select="COVERAGE/@version" />
	</xsl:variable>
	
	<xsl:variable name="power_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/POWER/@units" />
	</xsl:variable>
	
	<xsl:variable name="level_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LEVEL/@units" />
	</xsl:variable>
	
	<xsl:variable name="fm_deviation_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/FMDEVIATION/@units" />
	</xsl:variable>
	
	<xsl:variable name="cn_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/CN/@units" />
	</xsl:variable>  
	
	<xsl:variable name="mer_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/MER/@units" />
	</xsl:variable>  
	
	<!-- SFC: -->
	<xsl:variable name="ser_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/SER/@units" />
	</xsl:variable> 	
	<xsl:variable name="lm_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/LM/@units" />
	</xsl:variable>
	<xsl:variable name="va_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/VA/@units" />
	</xsl:variable>	
	<xsl:variable name="offset_units_label" as="xs:string">
		<xsl:value-of select="COVERAGE/CPOINT/MEASURES/OFFSET/@units" />
	</xsl:variable>	
	<!-- SFC: -->	
	
	<xsl:variable name="Error_Code_text" select="'Error Code: '" />
	<xsl:variable name="power_label" select="'Power '" /> 
	<xsl:variable name="level_label" select="'Level '" />
	<xsl:variable name="fm_deviation_label" select="'FM deviation '" />
	<xsl:variable name="cn_label" select="'CN '" /> 
	<xsl:variable name="mer_label" select="'MER '" /> 
	<!-- SFC: -->
	<xsl:variable name="cber_label" select="'CBER '" /> 
	<xsl:variable name="va_label" select="'VA '" /> 
	<xsl:variable name="lm_label" select="'LM '" /> 
	<xsl:variable name="offset_label" select="'Offset '" /> 
	<!-- SFC: -->	
	<xsl:variable name="open_label" select="' ('" />
	<xsl:variable name="close_label" select="')'" />
	
	<xsl:variable name="signal_type" as="xs:string">
		<xsl:for-each select="COVERAGE/INFORMATION/CHANNEL/MEASUREMENTS">
			<xsl:choose>
				<xsl:when test="DVB-T2">DVB-T2</xsl:when>
				<xsl:when test="DVB-T">DVB-T</xsl:when>
				<!-- SFC: -->
				<xsl:when test="DVB-C">DVB-C</xsl:when> 
				<xsl:when test="DVB-C2">DVB-C2</xsl:when>
				<xsl:when test="DAB">DAB</xsl:when> 
				<xsl:when test="DVB-S">DVB-S</xsl:when>
				<xsl:when test="DVB-S2">DVB-S2</xsl:when>
				<xsl:when test="ISDB-T">ISDB-T</xsl:when>
				<xsl:when test="ATSC">ATSC</xsl:when>
				<xsl:when test="ANALOGTER">ANALOG</xsl:when>
				<!-- SFC: -->
				<xsl:when test="FM">FM</xsl:when>
				<xsl:otherwise>ERROR</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:variable>
	
	<!-- 5.0 STYLES -->
	<xsl:template name='Styles_template'>
		<Styles>
			<Style ss:ID="Default" ss:Name="Normal">
				<Alignment ss:Vertical="Bottom" ss:Horizontal="Left"/>
				<Borders />
				<Font />
				<Interior />
				<NumberFormat />
				<Protection />
			</Style>
			<Style ss:ID="s20">
				<Font ss:Size="12" ss:Bold="1" />
			</Style>
			<Style ss:ID="s30">
				<Font ss:Size="12" ss:Bold="1" />
				<NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s21">
				<Font ss:Size="12" ss:Bold="1" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="2"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			</Style>
			<Style ss:ID="s31">
				<Font ss:Size="12" ss:Bold="1" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="2"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			   <NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s22">
				<Font ss:Size="12" ss:Bold="0" ss:Color="#0000FF"/>
			</Style>
			<Style ss:ID="s32">
				<Font ss:Size="12" ss:Bold="0" ss:Color="#0000FF"/>
				<NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s23">
				<Font ss:Size="12" ss:Bold="0" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			</Style>
			<Style ss:ID="s33">
				<Font ss:Size="12" ss:Bold="0" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
			   </Borders>
			   <NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s24">
				<Font ss:Size="12" ss:Bold="0" />
			</Style>
			<Style ss:ID="s34">
				<Font ss:Size="12" ss:Bold="0" />
				<NumberFormat ss:Format="Scientific"/>
			</Style>
			<Style ss:ID="s40">
				<Font ss:Size="12" ss:Bold="1" />
				<Alignment ss:Indent="0" ss:Vertical="Bottom" ss:Horizontal="Left" />
				<Borders>
					<Border ss:Position="Bottom" ss:LineStyle="Continuous" ss:Weight="2"/>
					<Border ss:Position="Left" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Right" ss:LineStyle="Continuous" ss:Weight="1"/>
					<Border ss:Position="Top" ss:LineStyle="Continuous" ss:Weight="1"/>
				</Borders>
				<Interior />
				<NumberFormat />
				<Protection />
			</Style>
		</Styles>
	</xsl:template>
	
</xsl:stylesheet>